@@ -217,6 +217,7 @@ static void start_moc (const struct parameters *params, lists_t_strs *args)
 				init_interface (server_sock, params->debug, args);
 				interface_loop ();
 				interface_end ();
+				server_sock = -1;
 			}
 		}
 		else
@@ -226,7 +227,10 @@ static void start_moc (const struct parameters *params, lists_t_strs *args)
 	if (!params->foreground && params->only_server)
 		send_int (server_sock, CMD_DISCONNECT);
 
-	close (server_sock);
+	if (server_sock != -1) {
+		close (server_sock);
+		server_sock = -1;
+	}
 }
 
 static void show_version ()
@@ -288,7 +292,7 @@ static void show_version ()
 	printf ("           Author : Damian Pietras\n");
 	printf ("         Homepage : %s\n", PACKAGE_URL);
 	printf ("           E-Mail : %s\n", PACKAGE_BUGREPORT);
-	printf ("        Copyright : (C) 2003-2014 Damian Pietras and others\n");
+	printf ("        Copyright : (C) 2003-2016 Damian Pietras and others\n");
 	printf ("          License : GNU General Public License, version 2 or later\n");
 	putchar ('\n');
 }
@@ -862,5 +866,5 @@ int main (int argc, char *argv[])
 	files_cleanup ();
 	compat_cleanup ();
 
-	exit (EXIT_SUCCESS);
+	return EXIT_SUCCESS;
 }
