@@ -13,6 +13,7 @@
 # include "config.h"
 #endif
 
+#include <stdio.h>
 #include <pthread.h>
 #include <string.h>
 #include <stdint.h>
@@ -815,6 +816,7 @@ static void play_stream (const struct decoder *f, struct out_buf *out_buf)
 
 		f->close (decoder_data);
 		error ("%s", err.err);
+		status_msg ("");
 		decoder_error_clear (&err);
 		logit ("Can't open file");
 	}
