@@ -531,7 +531,7 @@ static void on_song_change ()
 	case 0:
 		args = lists_strs_save (arg_list);
 		execve (args[0], args, environ);
-		exit (EXIT_SUCCESS);
+		exit (EXIT_FAILURE);
 	case -1:
 		logit ("Failed to fork(): %s", strerror (errno));
 	}
@@ -557,7 +557,7 @@ static void on_stop ()
 		switch (fork()) {
 			case 0:
 				execve (command, args, environ);
-				exit (EXIT_SUCCESS);
+				exit (EXIT_FAILURE);
 			case -1:
 				logit ("Error when running OnStop command '%s': %s",
 						command, strerror(errno));
@@ -1413,6 +1413,8 @@ static void handle_command (const int client_id)
 	switch (cmd) {
 		case CMD_QUIT:
 			logit ("Exit request from the client");
+			close (cli->socket);
+			del_client (cli);
 			server_quit = 1;
 			break;
 		case CMD_LIST_CLEAR:
@@ -1710,13 +1712,10 @@ void server_loop (int list_sock)
 		else
 			res = 0;
 
-		if (res == -1 && errno != EINTR && !server_quit) {
-			int err = errno;
+		if (res == -1 && errno != EINTR && !server_quit)
+			fatal ("select() failed: %s", strerror (errno));
 
-			logit ("select() failed: %s", strerror(err));
-			fatal ("select() failed: %s", strerror(err));
-		}
-		else if (!server_quit && res >= 0) {
+		if (!server_quit && res >= 0) {
 			if (FD_ISSET(list_sock, &fds_read)) {
 				int client_sock;
 
